//*****************************************************************************
// File Name            : msg_buf_ap.v
//-----------------------------------------------------------------------------
// Function             : serial ap
//                        
//-----------------------------------------------------------------------------
// Designer             : yokomizo 
//-----------------------------------------------------------------------------
// History
// -.-- 2010/8/27
// -.-- 2010/11/5
//*****************************************************************************
module msg_buf_ap(
RESETB, 
CLK,
TXD,
RXD,
LED_0,      
LED_1,      
LED_2,      
LED_3,      
LED_4,       
LED_5              
);
//            PIN NAME         description        
input         RESETB;         // power on reset    
input         CLK;         // main clk          
//                                      
output        TXD;         //serial tx data    
input         RXD;         //serial rx data
//
output        LED_0        ;
output        LED_1        ;
output        LED_2        ;
output        LED_3        ;
output        LED_4        ;
output        LED_5        ;
   
wire  [7:0]TX_DATA;        //tx data 8bit
wire       TX_DATA_EN;     //tx data enable 
wire        TX_BUSY;        //tx busy
wire        O_BUSY;        //tx busy
wire   [7:0]RX_DATA;        //rx data 8bit
wire        RX_DATA_EN;     //rx data enable 
wire   [7:0]MSG_DATA;       //message data 8bit
wire        MSG_DATA_EN;    //message data enable 
wire       RX_BUSY;        //Rx busy
wire   [15:0]CMD;
  
reg  [25:0] led_cnt;
   
parameter  led_cnt_1s = 26'd32999999; //1S CLK=33MHz

//LED$B@)8fMQ%+%&%s%?(B   
always @ (posedge CLK or negedge RESETB )
  if (RESETB==1'b0)
    led_cnt <= 26'b0;
  else if (led_cnt == led_cnt_1s) //1$BIC7P2a(B 
    led_cnt <= 26'b0;             //$B%+%&%s%HCM$r(B0
  else
    led_cnt <= led_cnt + 26'd1;   //$B%+%&%s%H%"%C%W(B

//LED$B@)8f(B   
assign LED_0 = (CMD[15:8]==8'h41)?1'b0: //LED$BE@Et(B
               (CMD[15:8]==8'h42)?1'b1: //LED$B>CEt(B
               (CMD[15:8]==8'h43)?((CMD[7:0]==8'h30)?led_cnt[15]: //LED$BE@LG(B
                                   (CMD[7:0]==8'h31)?led_cnt[16]:
                                   (CMD[7:0]==8'h32)?led_cnt[17]:
                                   (CMD[7:0]==8'h33)?led_cnt[18]:
                                   (CMD[7:0]==8'h34)?led_cnt[19]:
                                   (CMD[7:0]==8'h35)?led_cnt[20]:
                                   (CMD[7:0]==8'h36)?led_cnt[21]:
                                   (CMD[7:0]==8'h37)?led_cnt[22]:
                                   (CMD[7:0]==8'h38)?led_cnt[23]:
                                   (CMD[7:0]==8'h39)?led_cnt[24]:~led_cnt[24]):
                                   1'b1 ;    

assign LED_1 = LED_0;
assign LED_2 = LED_0;
assign LED_3 = LED_0;
assign LED_4 = LED_0;
assign LED_5 = LED_0;
   
   
rs232c_tx_rx  rs232c_tx_rx(
.RESETB(      RESETB),      
.CLK(        CLK),           
.TXD(        TXD),           
.RXD(        RXD),           
.TX_DATA(     TX_DATA),     
.TX_DATA_EN(  TX_DATA_EN),  
.TX_BUSY(     TX_BUSY),     
.RX_DATA(     RX_DATA),     
.RX_DATA_EN(  RX_DATA_EN),  
.RX_BUSY(      RX_BUSY))             
;
 
cmd_ctrl  cmd_ctrl(
.RESETB(      RESETB),      
.CLK(        CLK),        
.TX_DATA(     MSG_DATA),     
.TX_DATA_EN(  MSG_DATA_EN),  
.RX_DATA(     RX_DATA),     
.RX_DATA_EN(  RX_DATA_EN),    
.CMD(         CMD)
);
   
msg_buf msg_buf
( 
.CLK(       CLK),            
.RESET_N(   RESETB),     
.A_DAT_EN(  RX_DATA_EN),  
.A_DAT(     RX_DATA),     
.B_DAT_EN(  MSG_DATA_EN),  
.B_DAT(     MSG_DATA),     
.O_DAT(     TX_DATA),     
.O_DAT_EN(  TX_DATA_EN),
.O_BUSY(    TX_BUSY)   
);           
   
endmodule
