`timescale 1ns / 1ps
//*****************************************************************************
// File Name            : msg_buf_test.v
//-----------------------------------------------------------------------------
// Function             : message buffer and arbitartion test
//                        
//-----------------------------------------------------------------------------
// Designer             : yokomizo 
//-----------------------------------------------------------------------------
// History
// -.-- 2010/5/31
//*****************************************************************************
module msg_buf_test;
   
parameter data_width = 8   ;
parameter data_no = data_width -1;
parameter adr_width = 3   ;
parameter adr_no = adr_width -1;
parameter mem_size = (1 << adr_width)-1;
   
   
reg                   CLK;
reg                   RESETB;
reg                   A_DAT_EN;
reg     [data_no:0]   A_DAT;
wire                  A_N_FULL;
reg                   B_DAT_EN;
reg     [data_no:0]   B_DAT;
wire                  B_N_FULL;
wire                  O_DAT_EN;
wire     [data_no:0]  O_DAT;
reg                   O_BUSY;

msg_buf 

#(data_width,
  data_no,
  adr_width,
  adr_no,
  mem_size)

msg_buf
( 
.CLK(       CLK),            
.RESET_N(   RESETB),     
.A_DAT_EN(  A_DAT_EN),  
.A_DAT(     A_DAT),     
.A_N_FULL(    A_N_FULL),     
.B_DAT_EN(  B_DAT_EN),  
.B_DAT(     B_DAT),    
.B_N_FULL(    B_N_FULL),      
.O_DAT(     O_DAT),     
.O_DAT_EN(  O_DAT_EN),
.O_BUSY(    O_BUSY)   
);           


        initial begin
                // Initialize Inputs
                RESETB = 0;

                // Wait 100 ns for global reset to finish
                #100;
                RESETB = 1;
        end
     
        initial begin
                // Initialize Inputs
                CLK = 0;
                repeat(500000000) begin
                #12.5;
                CLK = 1;
                #12.5;
                CLK = 0;
                end
                $stop;
        end // initial begin

   
        initial begin
                // Initialize Inputs
                A_DAT =8'h0;
                A_DAT_EN = 1'b0;
       
                // Wait 100 ns for global reset to finish
                #200;
                repeat(8) begin
                  A_DAT = A_DAT +8'h1 ;
                  A_DAT_EN = 1'b1;
                  #25;
                  A_DAT = A_DAT + 8'h1 ;
                  #25;
                  A_DAT = A_DAT + 8'h1 ;
                  #25;
                  A_DAT = A_DAT + 8'h1 ;
                  #25;
                  A_DAT_EN = 1'b0;
                  #400;
                end
                #100;
                repeat(16) begin
                  if(A_N_FULL==1'b0)
                    begin 
                      A_DAT = A_DAT + 8'h1 ;
                      A_DAT_EN = 1'b1;
                    end
                  else
                    begin 
                      A_DAT = A_DAT ;
                      A_DAT_EN = 1'b0;
                    end
                  #25;
                end
                A_DAT_EN = 1'b0;
                #1000;
        end // initial begin
   
        initial begin
                // Initialize Inputs
                B_DAT =8'h80;
                B_DAT_EN = 1'b0;
       
                // Wait 100 ns for global reset to finish
                #325;
                repeat(8) begin
                  B_DAT = B_DAT + 8'h1 ;
                  B_DAT_EN = 1'b1;
                  #25;
                  B_DAT = B_DAT + 8'h1 ;
                  #25;
                  B_DAT = B_DAT + 8'h1 ;
                  #25;
                  B_DAT = B_DAT + 8'h1 ;
                  #25;
                  B_DAT_EN = 1'b0;
                  #375;
                end
                #700;
                repeat(16) begin
                  if(B_N_FULL==1'b0)
                    begin 
                      B_DAT = B_DAT + 8'h1 ;
                      B_DAT_EN = 1'b1;
                    end
                  else
                    begin 
                      B_DAT = B_DAT ;
                      B_DAT_EN = 1'b0;
                    end
                  #25;
                end
                B_DAT_EN = 1'b0;
                #1000;
                $stop;     
        end // initial begin
   
        initial begin
                // Initialize Inputs
                O_BUSY = 1'b0;
                #3700;
                repeat(10) begin
                  O_BUSY = 1'b0;
                  #25;
                  O_BUSY = 1'b1;
                  #25;
                end
                O_BUSY = 1'b0;
                #100;
                O_BUSY = 1'b1;
                #400;
                O_BUSY = 1'b0;
                #2200;
                $stop;     
        end // initial begin
   
endmodule
